@@ -1,20 +1,6 @@
-/* Copyright (C) 2014-2022 Greenbone Networks GmbH
+/* SPDX-FileCopyrightText: 2014-2023 Greenbone AG
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -125,6 +111,9 @@ static const osp_get_vts_opts_t osp_get_vts_opts_default = {NULL, 0};
 int
 osp_get_vts_ext (osp_connection_t *, osp_get_vts_opts_t, entity_t *);
 
+int
+osp_get_vts_ext_str (osp_connection_t *, osp_get_vts_opts_t, gchar **);
+
 int
 osp_start_scan (osp_connection_t *, const char *, const char *, GHashTable *,
                 const char *, char **);
